# Makefile for LaTeX 300 lines per inch fonts.
# Based on the gf300.makefile
# contributed by John Ramsdell of the MITRE Corp., Bedford, MA.

# You can change the resolution for all magsteps with a single line
# modeled on make depend.
#		 make magsteps "DPI=nnn"
# where nnn is the DPI resolution
# of your printer.
# NOTE: If you have only the fonts for a LaTeX 10pt style, and you
# want to be sure of *ALL* the magnifications necessary for a
# 12pt style ( == magstep1), simply increase the DPI value
# and run a make.  For example, if you are starting from 300dpi,
# and you want all necessary fonts at magstep1, begin with
#		make magsteps "DPI=360"
# and then make all.
#
# Copy this Makefile to the directory where you want the gf files
# to appear.  Then copy or link all relevant top-level parameter files
# in that directory (e.g. cmr10.mf)
# The *.mf files must be present in or linked in that directory
# so that make can evaluate its targets.  Sorry about that.
#
# Check the following lines out for compatibility with your system
# Invoke this with make "MF=mymf" "MODE=mymode" to get special
# effects.  For instance, to make the gf300w fonts, the
# call would be:    make all "MODE=RicohFourZeroEightZero"

BIN	= /usr/local/bin
MFBIN	= $(BIN)
MF	= mf
MFBASE  = /usr/local/lib/mf/bases
OPT	= scrollmode
#CMDLINE	= MFBASES=${MFBASE} ; export MFBASES ; $(MFBIN)/$(MF) '\mode:=$(MODE);' '$(OPT);'
CMDLINE	= MFBASES=${MFBASE} ; export MFBASES ; $(MFBIN)/$(MF) '\mode:=$(MODE);'

# WARNING!                 WARNING!                 WARNING!

# WARNING: This script should NOT use a base in which cmbase has been
# preloaded.  The cm*.mf files which are mentioned below will
# read cmbase.mf if it is needed, while the lasy*.mf line*.mf and
# lcircle*.mf will give incorrect results if cmbase is preloaded

# for purposes of this script, "mf.base" is assumed to include
# the local |mode_def| file (e.g. U_Wash.mf).


# BEGIN MAGSTEPS DO NOT DELETE THIS LINE
# OR THIS LINE--the following macros are generated by make magsteps
DPI	=  300
MODE	=  hplaser
DPI_MAGHALF	=  329
DPI_MAGONE	=  360
DPI_MAGHALFONE	=  394
DPI_MAGTWO	=  432
DPI_MAGTHREE	=  518
DPI_MAGFOUR	=  622
DPI_MAGFIVE	=  746
DPI_MAGSIX	=  895
DPI_MAGSEVEN	=  1074
DPI_MAGEIGHT	=  1289
DPI_MAGNINE	=  1547
TEN_AT_NINE	=  270
TEN_AT_EIGHT	=  240
SVN_AT_SIX	=  257
SVN_AT_FIVE	=  214
# END MAGSTEPS DO NOT DELETE THIS LINE EITHER

PKDEST	= /usr/local/lib/tex/fonts/${DPI}pk
TFMDEST	= /usr/local/lib/tex/fonts/tfm

.SUFFIXES: .mf .${DPI}gf 
.SUFFIXES: .${DPI_MAGHALF}gf .${DPI_MAGONE}gf .${DPI_MAGHALFONE}gf .${DPI_MAGTWO}gf .${DPI_MAGTHREE}gf .${DPI_MAGFOUR}gf .${DPI_MAGFIVE}gf
.SUFFIXES: .${DPI_MAGSIX}gf .${DPI_MAGSEVEN}gf .${DPI_MAGEIGHT}gf .${DPI_MAGNINE}gf
.SUFFIXES: .$(TEN_AT_NINE)gf .$(SVN_AT_SIX)gf .$(TEN_AT_EIGHT)gf .$(SVN_AT_FIVE)gf

.mf.${DPI}gf:
	(if test ! -d ${PKDEST}/${DPI}; then mkdir ${PKDEST}/${DPI}; fi)
	(if test ! -f ${PKDEST}/${DPI}/$*.pk; then \
	$(CMDLINE) input $* </dev/null; \
	gftopk $*.${DPI}gf ${PKDEST}/${DPI}/$*.pk; \
	mv $*.tfm ${TFMDEST};\
	rm -f $*.${DPI}gf; \
	touch $*.${DPI}gf; \
	fi)

.mf.${DPI_MAGHALF}gf:
	(if test ! -d ${PKDEST}/${DPI_MAGHALF}; then mkdir ${PKDEST}/${DPI_MAGHALF}; fi)
	(if test ! -f ${PKDEST}/${DPI_MAGHALF}/$*.pk; then \
	$(CMDLINE) 'mag:=magstep(1.0);' input $* </dev/null; \
	gftopk $*.${DPI_MAGHALF}gf ${PKDEST}/${DPI_MAGHALF}/$*.pk; \
	mv $*.tfm ${TFMDEST};\
	rm -f $*.${DPI_MAGHALF}gf; \
	touch $*.${DPI_MAGHALF}gf; \
	fi)

.mf.${DPI_MAGONE}gf:
	(if test ! -d ${PKDEST}/${DPI_MAGONE}; then mkdir ${PKDEST}/${DPI_MAGONE}; fi)
	(if test ! -f ${PKDEST}/${DPI_MAGONE}/$*.pk; then \
	$(CMDLINE) 'mag:=magstep(1.0);' input $* </dev/null; \
	gftopk $*.${DPI_MAGONE}gf ${PKDEST}/${DPI_MAGONE}/$*.pk; \
	mv $*.tfm ${TFMDEST};\
	rm -f $*.${DPI_MAGONE}gf; \
	touch $*.${DPI_MAGONE}gf; \
	fi)

.mf.${DPI_MAGTWO}gf:
	(if test ! -d ${PKDEST}/${DPI_MAGTWO}; then mkdir ${PKDEST}/${DPI_MAGTWO}; fi)
	(if test ! -f ${PKDEST}/${DPI_MAGTWO}/$*.pk; then \
	$(CMDLINE) 'mag:=magstep(2.0);' input $* </dev/null; \
	gftopk $*.${DPI_MAGTWO}gf ${PKDEST}/${DPI_MAGTWO}/$*.pk; \
	mv $*.tfm ${TFMDEST};\
	rm -f $*.${DPI_MAGTWO}gf; \
	touch $*.${DPI_MAGTWO}gf; \
	fi)

.mf.${DPI_MAGTHREE}gf:
	(if test ! -d ${PKDEST}/${DPI_MAGTHREE}; then mkdir ${PKDEST}/${DPI_MAGTHREE}; fi)
	(if test ! -f ${PKDEST}/${DPI_MAGTHREE}/$*.pk; then \
	$(CMDLINE) 'mag:=magstep(3.0);' input $* </dev/null; \
	gftopk $*.${DPI_MAGTHREE}gf ${PKDEST}/${DPI_MAGTHREE}/$*.pk; \
	mv $*.tfm ${TFMDEST};\
	rm -f $*.${DPI_MAGTHREE}gf; \
	touch $*.${DPI_MAGTHREE}gf; \
	fi)

.mf.${DPI_MAGFOUR}gf:
	(if test ! -d ${PKDEST}/${DPI_MAGFOUR}; then mkdir ${PKDEST}/${DPI_MAGFOUR}; fi)
	(if test ! -f ${PKDEST}/${DPI_MAGFOUR}/$*.pk; then \
	$(CMDLINE) 'mag:=magstep(4.0);' input $* </dev/null; \
	gftopk $*.${DPI_MAGFOUR}gf ${PKDEST}/${DPI_MAGFOUR}/$*.pk; \
	mv $*.tfm ${TFMDEST};\
	rm -f $*.${DPI_MAGFOUR}gf; \
	touch $*.${DPI_MAGFOUR}gf; \
	fi)

.mf.${DPI_MAGFIVE}gf:
	(if test ! -d ${PKDEST}/${DPI_MAGFIVE}; then mkdir ${PKDEST}/${DPI_MAGFIVE}; fi)
	(if test ! -f ${PKDEST}/${DPI_MAGFIVE}/$*.pk; then \
	$(CMDLINE) 'mag:=magstep(5.0);' input $* </dev/null; \
	gftopk $*.${DPI_MAGFIVE}gf ${PKDEST}/${DPI_MAGFIVE}/$*.pk; \
	mv $*.tfm ${TFMDEST}; \
	rm -f $*.${DPI_MAGFIVE}gf; \
	touch $*.${DPI_MAGFIVE}gf; \
	fi)

.mf.${DPI_MAGSIX}gf:
	(if test ! -d ${PKDEST}/${DPI_MAGSIX}; then mkdir ${PKDEST}/${DPI_MAGSIX}; fi)
	(if test ! -f ${PKDEST}/${DPI_MAGSIX}/$*.pk; then \
	$(CMDLINE) 'mag:=magstep(6.0);' input $* </dev/null; \
	gftopk $*.${DPI_MAGSIX}gf ${PKDEST}/${DPI_MAGSIX}/$*.pk; \
	mv $*.tfm ${TFMDEST};\
	rm -f $*.${DPI_MAGSIX}gf; \
	touch $*.${DPI_MAGSIX}gf; \
	fi)

.mf.${DPI_MAGSEVEN}gf:
	(if test ! -d ${PKDEST}/${DPI_MAGSEVEN}; then mkdir ${PKDEST}/${DPI_MAGSEVEN}; fi)
	(if test ! -f ${PKDEST}/${DPI_MAGSEVEN}/$*.pk; then \
	$(CMDLINE) 'mag:=magstep(7.0);' input $* </dev/null; \
	gftopk $*.${DPI_MAGSEVEN}gf ${PKDEST}/${DPI_MAGSEVEN}/$*.pk; \
	mv $*.tfm ${TFMDEST};\
	rm -f $*.${DPI_MAGSEVEN}gf; \
	touch $*.${DPI_MAGSEVEN}gf; \
	fi)

.mf.${DPI_MAGEIGHT}gf:
	(if test ! -d ${PKDEST}/${DPI_MAGEIGHT}; then mkdir ${PKDEST}/${DPI_MAGEIGHT}; fi)
	(if test ! -f ${PKDEST}/${DPI_MAGEIGHT}/$*.pk; then \
	$(CMDLINE) 'mag:=magstep(8.0);' input $* </dev/null; \
	gftopk $*.${DPI_MAGEIGHT}gf ${PKDEST}/${DPI_MAGEIGHT}/$*.pk; \
	mv $*.tfm ${TFMDEST};\
	rm -f $*.${DPI_MAGEIGHT}gf; \
	touch $*.${DPI_MAGEIGHT}gf; \
	fi)

.mf.${DPI_MAGNINE}gf:
	(if test ! -d ${PKDEST}/${DPI_MAGNINE}; then mkdir ${PKDEST}/${DPI_MAGNINE}; fi)
	(if test ! -f ${PKDEST}/${DPI_MAGNINE}/$*.pk; then \
	$(CMDLINE) 'mag:=magstep(9.0);' input $* </dev/null; \
	gftopk $*.${DPI_MAGNINE}gf ${PKDEST}/${DPI_MAGNINE}/$*.pk; \
	mv $*.tfm ${TFMDEST};\
	rm -f $*.${DPI_MAGNINE}gf; \
	touch $*.${DPI_MAGNINE}gf; \
	fi)

NOMAG	= lasy10.${DPI}gf lasy5.${DPI}gf lasy6.${DPI}gf lasy7.${DPI}gf lasy8.${DPI}gf \
	lasy9.${DPI}gf lasyb10.${DPI}gf lcircle10.${DPI}gf lcirclew10.${DPI}gf \
	line10.${DPI}gf linew10.${DPI}gf

MAGHALF	= lasy10.${DPI_MAGHALF}gf lasy5.${DPI_MAGHALF}gf lasy7.${DPI_MAGHALF}gf lasyb10.${DPI_MAGHALF}gf

MAGONE	= lasy10.${DPI_MAGONE}gf lasy5.${DPI_MAGONE}gf lasy7.${DPI_MAGONE}gf lasyb10.${DPI_MAGONE}gf

MAGTWO	= lasy10.${DPI_MAGTWO}gf lasy5.${DPI_MAGTWO}gf lasy7.${DPI_MAGTWO}gf lasyb10.${DPI_MAGTWO}gf

MAGTHREE = lasy10.${DPI_MAGTHREE}gf lasy5.${DPI_MAGTHREE}gf lasy7.${DPI_MAGTHREE}gf lasy8.${DPI_MAGTHREE}gf lasyb10.${DPI_MAGTHREE}gf \
	lcmss8.${DPI_MAGTHREE}gf lcmssi8.${DPI_MAGTHREE}gf lcmssb8.${DPI_MAGTHREE}gf \
	cmmi8.${DPI_MAGTHREE}gf cmsy8.${DPI_MAGTHREE}gf cmtt8.${DPI_MAGTHREE}gf cmex10.${DPI_MAGTHREE}gf \
	ilcmss8.${DPI_MAGTHREE}gf ilcmssi8.${DPI_MAGTHREE}gf ilcmssb8.${DPI_MAGTHREE}gf \
	icmmi8.${DPI_MAGTHREE}gf icmsy8.${DPI_MAGTHREE}gf icmtt8.${DPI_MAGTHREE}gf icmex10.${DPI_MAGTHREE}gf ilasy8.${DPI_MAGTHREE}gf

MAGFOUR = lasy10.${DPI_MAGFOUR}gf lasy5.${DPI_MAGFOUR}gf lasy7.${DPI_MAGFOUR}gf lasy8.${DPI_MAGFOUR}gf lasyb10.${DPI_MAGFOUR}gf \
	lcmss8.${DPI_MAGFOUR}gf lcmssi8.${DPI_MAGFOUR}gf lcmssb8.${DPI_MAGFOUR}gf \
	cmmi8.${DPI_MAGFOUR}gf cmsy8.${DPI_MAGFOUR}gf cmtt8.${DPI_MAGFOUR}gf \
	ilcmss8.${DPI_MAGFOUR}gf ilcmssi8.${DPI_MAGFOUR}gf ilcmssb8.${DPI_MAGFOUR}gf \
	icmmi8.${DPI_MAGFOUR}gf icmsy8.${DPI_MAGFOUR}gf icmtt8.${DPI_MAGFOUR}gf ilasy8.${DPI_MAGFOUR}gf

MAGFIVE = lasy10.${DPI_MAGFIVE}gf lasy5.${DPI_MAGFIVE}gf lasy7.${DPI_MAGFIVE}gf lasy8.${DPI_MAGFIVE}gf lasyb10.${DPI_MAGFIVE}gf \
	lcmss8.${DPI_MAGFIVE}gf lcmssi8.${DPI_MAGFIVE}gf lcmssb8.${DPI_MAGFIVE}gf \
	cmmi8.${DPI_MAGFIVE}gf cmsy8.${DPI_MAGFIVE}gf cmtt8.${DPI_MAGFIVE}gf \
	ilcmss8.${DPI_MAGFIVE}gf ilcmssi8.${DPI_MAGFIVE}gf ilcmssb8.${DPI_MAGFIVE}gf \
	icmmi8.${DPI_MAGFIVE}gf icmsy8.${DPI_MAGFIVE}gf icmtt8.${DPI_MAGFIVE}gf ilasy8.${DPI_MAGFIVE}gf

MAGSIX	= lasy8.${DPI_MAGSIX}gf \
	lcmss8.${DPI_MAGSIX}gf lcmssi8.${DPI_MAGSIX}gf lcmssb8.${DPI_MAGSIX}gf \
	cmmi8.${DPI_MAGSIX}gf cmsy8.${DPI_MAGSIX}gf cmtt8.${DPI_MAGSIX}gf \
	ilcmss8.${DPI_MAGSIX}gf ilcmssi8.${DPI_MAGSIX}gf ilcmssb8.${DPI_MAGSIX}gf \
	icmmi8.${DPI_MAGSIX}gf icmsy8.${DPI_MAGSIX}gf icmtt8.${DPI_MAGSIX}gf ilasy8.${DPI_MAGSIX}gf

MAGSEVEN = lasy8.${DPI_MAGSEVEN}gf \
	lcmss8.${DPI_MAGSEVEN}gf lcmssi8.${DPI_MAGSEVEN}gf lcmssb8.${DPI_MAGSEVEN}gf \
	cmmi8.${DPI_MAGSEVEN}gf cmsy8.${DPI_MAGSEVEN}gf cmtt8.${DPI_MAGSEVEN}gf \
	ilcmss8.${DPI_MAGSEVEN}gf ilcmssi8.${DPI_MAGSEVEN}gf ilcmssb8.${DPI_MAGSEVEN}gf \
	icmmi8.${DPI_MAGSEVEN}gf icmsy8.${DPI_MAGSEVEN}gf icmtt8.${DPI_MAGSEVEN}gf ilasy8.${DPI_MAGSEVEN}gf

MAGEIGHT = lasy8.${DPI_MAGEIGHT}gf \
	lcmss8.${DPI_MAGEIGHT}gf lcmssi8.${DPI_MAGEIGHT}gf lcmssb8.${DPI_MAGEIGHT}gf \
	cmmi8.${DPI_MAGEIGHT}gf cmsy8.${DPI_MAGEIGHT}gf cmtt8.${DPI_MAGEIGHT}gf \
	ilcmss8.${DPI_MAGEIGHT}gf ilcmssi8.${DPI_MAGEIGHT}gf ilcmssb8.${DPI_MAGEIGHT}gf \
	icmmi8.${DPI_MAGEIGHT}gf icmsy8.${DPI_MAGEIGHT}gf icmtt8.${DPI_MAGEIGHT}gf ilasy8.${DPI_MAGEIGHT}gf

MAGNINE = lcmss8.${DPI_MAGNINE}gf ilcmss8.${DPI_MAGNINE}gf

SLIDELOGO = logo8.${DPI_MAGTHREE}gf logo8.${DPI_MAGFOUR}gf logo8.${DPI_MAGFIVE}gf logo8.${DPI_MAGSIX}gf logo8.${DPI_MAGSEVEN}gf logo8.${DPI_MAGEIGHT}gf

FONTS = $(NOMAG) $(MAGHALF) $(MAGONE) $(MAGTWO) $(MAGTHREE) $(MAGFOUR) \
	$(MAGFIVE) $(MAGSIX) $(MAGSEVEN) $(MAGEIGHT) $(MAGNINE)

all:	$(FONTS)

logo:   $(SLIDELOGO)

# Nice bit of self-reference here, as DPI uses itself to recreate itself
#
magsteps:
	(base=$(DPI) ; mode=$(MODE) ; \
	echo "DPI	= " $$base > magvals ; \
	echo "MODE	= " $$mode >> magvals ; \
	i=`/bin/expr $$base \* 95445` ; \
	j=`/bin/expr $$base \* 1000000 + $$i + 500000` ; \
	maghalf=`/bin/expr $$j / 1000000` ; \
	echo "DPI_MAGHALF	= " $$maghalf >> magvals ; \
	i=`/bin/expr  $$base \* 2` ; j=`/bin/expr $$base \* 10 + $$i + 5` ; magone=`/bin/expr $$j / 10` ; \
	echo "DPI_MAGONE	= " $$magone >> magvals ; \
	i=`/bin/expr  $$magone \* 95445` ; j=`/bin/expr $$magone \* 1000000 + $$i + 500000` ; \
	maghalfone=`/bin/expr $$j / 1000000` ; \
	echo "DPI_MAGHALFONE	= " $$maghalfone >> magvals ; \
	i=`/bin/expr  $$magone \* 2` ; j=`/bin/expr $$magone \* 10 + $$i + 5` ; \
	magtwo=`/bin/expr $$j / 10` ; echo "DPI_MAGTWO	= " $$magtwo >> magvals ; \
	i=`/bin/expr  $$magtwo \* 2` ; j=`/bin/expr $$magtwo \* 10 + $$i + 5` ; \
	magthree=`/bin/expr $$j / 10` ; echo "DPI_MAGTHREE	= " $$magthree >> magvals ; \
	i=`/bin/expr  $$magthree \* 2` ; j=`/bin/expr $$magthree \* 10 + $$i + 5` ; \
	magfour=`/bin/expr $$j / 10` ; echo "DPI_MAGFOUR	= " $$magfour >> magvals ; \
	i=`/bin/expr  $$magfour \* 2` ; j=`/bin/expr $$magfour \* 10 + $$i + 5` ; \
	magfive=`/bin/expr $$j / 10` ; echo "DPI_MAGFIVE	= " $$magfive >> magvals ; \
	i=`/bin/expr  $$magfive \* 2` ; j=`/bin/expr $$magfive \* 10 + $$i + 5` ; \
	magsix=`/bin/expr $$j / 10` ; echo "DPI_MAGSIX	= " $$magsix >> magvals ; \
	i=`/bin/expr  $$magsix \* 2` ; j=`/bin/expr $$magsix \* 10 + $$i + 5` ; \
	magseven=`/bin/expr $$j / 10` ; echo "DPI_MAGSEVEN	= " $$magseven >> magvals ; \
	i=`/bin/expr  $$magseven \* 2` ; j=`/bin/expr $$magseven \* 10 + $$i + 5` ; \
	mageight=`/bin/expr $$j / 10` ; echo "DPI_MAGEIGHT	= " $$mageight >> magvals ; \
	i=`/bin/expr  $$mageight \* 2` ; j=`/bin/expr $$mageight \* 10 + $$i + 5` ; \
	magnine=`/bin/expr $$j / 10` ; echo "DPI_MAGNINE	= " $$magnine >> magvals ; \
	i=`/bin/expr $$base \* 900` ; \
	tenatnine=`/bin/expr $$i / 1000` ; \
	echo "TEN_AT_NINE	= " $$tenatnine >> magvals ; \
	i=`/bin/expr $$base \* 800` ; \
	tenateight=`/bin/expr $$i / 1000` ; \
	echo "TEN_AT_EIGHT	= " $$tenateight >> magvals ; \
	i=`/bin/expr $$base \* 600` ; \
	svnatsix=`/bin/expr $$i / 700` ; \
	echo "SVN_AT_SIX	= " $$svnatsix >> magvals ; \
	i=`/bin/expr $$base \* 500` ; \
	svnatfive=`/bin/expr $$i / 700` ; \
	echo "SVN_AT_FIVE	= " $$svnatfive >> magvals ; \
	echo "# END MAGSTEPS DO NOT DELETE THIS LINE EITHER" >> magvals)
	cp LaTeX.make LaTeX.bak
	(if [ "$(DPI)" = "240" ]; then \
	sed -e "s/598/597/g" magvals | sed -e "s/718/717/g" | sed -e "s/862/860/g" | sed -e "s/1034/1032/g" | sed -e "s/1241/1238/g" > magvals.tmp; \
	mv magvals.tmp magvals; \
	fi) 
	echo '/^# BEGIN MAGSTEPS/+2,/^# END MAGSTEPS/d|-1r magvals |w' | ex LaTeX.make
#	Here is some boilerplate for additional dependencies. Try your hand.
#	echo '/^# DO NOT DELETE THIS LINE/+2,$$d|w' | ex LaTeX.make

#	echo '# GENERATED DEPENDENCIES MUST BE AT EOF' >> LaTeX.make
#	echo '# IF YOU PUT STUFF HERE IT WILL GO AWAY' >> LaTeX.make

# DO NOT DELETE THIS LINE
# OR THIS LINE--the following rules are generated by make depend
# GENERATED DEPENDENCIES MUST BE AT EOF
# IF YOU PUT STUFF HERE IT WILL GO AWAY
